@@ -2,7 +2,6 @@
 
 import errno
 import pickle
-import sys
 from unittest import mock
 
 import pytest
@@ -59,7 +58,7 @@ class TestClientResponseError:
 
     def test_repr(self) -> None:
         err = client.ClientResponseError(request_info=self.request_info, history=())
-        assert repr(err) == ("ClientResponseError(%r, ())" % (self.request_info,))
+        assert repr(err) == (f"ClientResponseError({self.request_info!r}, ())")
 
         err = client.ClientResponseError(
             request_info=self.request_info,
@@ -163,7 +162,7 @@ class TestClientConnectorError:
             connection_key=self.connection_key, os_error=os_error
         )
         assert repr(err) == (
-            "ClientConnectorError(%r, %r)" % (self.connection_key, os_error)
+            f"ClientConnectorError({self.connection_key!r}, {os_error!r})"
         )
 
     def test_str(self) -> None:
@@ -252,16 +251,10 @@ class TestServerDisconnectedError:
 
     def test_repr(self) -> None:
         err = client.ServerDisconnectedError()
-        if sys.version_info < (3, 7):
-            assert repr(err) == ("ServerDisconnectedError" "('Server disconnected',)")
-        else:
-            assert repr(err) == ("ServerDisconnectedError" "('Server disconnected')")
+        assert repr(err) == ("ServerDisconnectedError" "('Server disconnected')")
 
         err = client.ServerDisconnectedError(message="No connection")
-        if sys.version_info < (3, 7):
-            assert repr(err) == "ServerDisconnectedError('No connection',)"
-        else:
-            assert repr(err) == "ServerDisconnectedError('No connection')"
+        assert repr(err) == "ServerDisconnectedError('No connection')"
 
     def test_str(self) -> None:
         err = client.ServerDisconnectedError()
